@@ -83,6 +83,7 @@ def train_from_folder(
     evaluate_every = 1000,
     generate = False,
     generate_interpolation = False,
+    hamburger_res_layers = [],
     interpolation_num_steps = 100,
     save_frames = False,
     num_image_tiles = 8,
@@ -101,6 +102,7 @@ def train_from_folder(
         models_dir = models_dir,
         batch_size = batch_size,
         gradient_accumulate_every = gradient_accumulate_every,
+        hamburger_res_layers = cast_list(hamburger_res_layers),
         image_size = image_size,
         fmap_max = fmap_max,
         transparent = transparent,
